# use Python 3 on Fedora 22 or higher
%if 0%{?fedora} >= 22
%bcond_without python3
%else
%bcond_with python3
%endif

%global commit be7907c0138c0b9f05a84d44fd6e41ff397d407e
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%global checkout 20150702git%{shortcommit}

%global gh_owner brutasse
%global gh_project graphite-api

Name:           graphite-api
Version:        1.0.1
Release:        4.%{checkout}%{?dist}
Summary:        Graphite-web, without the interface. Just the rendering HTTP API

License:        ASL 2.0
URL:            https://github.com/brutasse/graphite-api
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{commit}/%{gh_project}-%{commit}.tar.gz
Source1:        graphite-api.yaml
Source2:        graphite-api.sysconfig
Source3:        graphite-api.service

BuildArch:      noarch

BuildRequires:  systemd
Requires(pre):  shadow-utils
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%if %{with python3}
BuildRequires:  python3-cairocffi
BuildRequires:  python3-cffi
BuildRequires:  python3-devel
BuildRequires:  python3-flask
BuildRequires:  python3-flask-cache
BuildRequires:  python3-itsdangerous
BuildRequires:  python3-mock
BuildRequires:  python3-pyparsing
BuildRequires:  python3-pytest
BuildRequires:  python3-pytz
BuildRequires:  python3-PyYAML
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
BuildRequires:  python3-structlog
BuildRequires:  python3-six
BuildRequires:  python3-tzlocal
BuildRequires:  python3-werkzeug
Requires:       python3-pyparsing
Requires:       python3-cairocffi
Requires:       python3-cffi
Requires:       python3-flask
Requires:       python3-flask-cache
Requires:       python3-gunicorn
Requires:       python3-itsdangerous
Requires:       python3-structlog
Requires:       python3-six
Requires:       python3-tzlocal
Requires:       python3-werkzeug
Requires:       python3-pytz
Requires:       python3-PyYAML
%else
BuildRequires:  pyparsing
BuildRequires:  pytest
BuildRequires:  python-cairocffi
BuildRequires:  python-cffi
BuildRequires:  python2-devel
BuildRequires:  python-flask
BuildRequires:  python-flask-cache
BuildRequires:  python-itsdangerous
BuildRequires:  python-mock
BuildRequires:  python-setuptools
BuildRequires:  python-sphinx
BuildRequires:  python-structlog
BuildRequires:  python-six
BuildRequires:  python-tzlocal
BuildRequires:  python-werkzeug
BuildRequires:  pytz
BuildRequires:  PyYAML
Requires:       pyparsing
Requires:       python-cairocffi
Requires:       python-carbon
Requires:       python-cffi
Requires:       python-flask
Requires:       python-flask-cache
Requires:       python-gunicorn
Requires:       python-itsdangerous
Requires:       python-structlog
Requires:       python-six
Requires:       python-tzlocal
Requires:       python-werkzeug
Requires:       python-whisper
Requires:       pytz
Requires:       PyYAML
%endif


%description
Graphite-API is an alternative to Graphite-web, without any built-in dashboard.
Its role is solely to fetch metrics from a time-series database (whisper, 
cyanite, etc.) and rendering graphs or JSON data out of these time series. It 
is meant to be consumed by any of the numerous Graphite dashboard applications.


#%package doc
#Summary:        Documentation for graphite-api
#%if %{with python3}
#BuildRequires:  python3-sphinx
#BuildRequires:  python3-sphinx_rtd_theme
#%else
#BuildRequires:  python-sphinx
#BuildRequires:  python-sphinx_rtd_theme
#%endif
#
#
#%description doc
#Documentation for graphite-api
#

%prep
%setup -q -n %{gh_project}-%{commit}


%build
%if %{with python3}
%{__python3} setup.py build
sed -i 's|/usr/bin/gunicorn|/usr/bin/python3-gunicorn|' %{SOURCE3}
#pushd docs
#sphinx-build-3 -b html -d build/doctrees . build/html
#rm -f build/html/.buildinfo
#sed -i 's/\r$//' build/html/_static/jquery.js
#popd
%else
%{__python2} setup.py build
# building docs fails on sphinx 1.2.x
#pushd docs
#sphinx-build -b html -d build/doctrees . build/html
#rm -f build/html/.buildinfo
#sed -i 's/\r$//' build/html/_static/jquery.js
#popd
%endif


%install
%if %{with python3}
%{__python3} setup.py install --skip-build --root %{buildroot}
%else
%{__python2} setup.py install --skip-build --root %{buildroot}
%endif

%{__install} -Dp -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/graphite-api.yaml
%{__install} -Dp -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -Dp -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service

# Create directories
%{__mkdir_p} %{buildroot}%{_sharedstatedir}/graphite-api


%check
%if %{with python3}
py.test-3.4 tests
%else
py.test-2.7 tests
%endif


%pre
getent group graphite-api >/dev/null || groupadd -r graphite-api
getent passwd graphite-api >/dev/null || \
    useradd -r -g graphite-api -d / -s /sbin/nologin \
    -c "graphite-api daemon user" graphite-api
exit 0


%post
%systemd_post %{name}.service


%preun
%systemd_preun %{name}.service


%postun
%systemd_postun_with_restart %{name}.service


%files
%doc README.rst CONTRIBUTING.md
%license LICENSE
%config(noreplace) %{_sysconfdir}/graphite-api.yaml
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{_sharedstatedir}/graphite-api
%{_unitdir}/%{name}.service

%if %{with python3}
%{python3_sitelib}/graphite_api*
%else
%{python2_sitelib}/graphite_api*
%endif


#%files doc
#%doc docs/*.rst docs/build/html


%changelog
* Thu Jul 09 2015 Piotr Popieluch <piotr1212@gmail.com> - 1.0.1-4.20150702gitbe7907c
- fix lint warnings

* Thu Jul 02 2015 Piotr Popieluch <piotr1212@gmail.com> - 1.0.1-3.20150702gitbe7907c
- update to github master head
- moved license to %%license
- fix buildrequires

* Wed Oct 22 2014 Piotr Popieluch <piotr1212@gmail.com> - 1.0.1-2
- added %%check
- patch for timezone issue and to pass the %%check
- made python version explicit

* Sat Oct 11 2014 Piotr Popieluch <piotr1212@gmail.com> - 1.0.1-1
- Initial package

